# Generated by Django 4.2.25 on 2025-10-30 17:38

# Django
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("aapayout", "0004_remove_fleet_doctrine_remove_fleet_location_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="fleet",
            name="finalized",
            field=models.BooleanField(
                default=False,
                help_text="Whether this fleet has been finalized (triggers wallet verification)",
            ),
        ),
        migrations.AddField(
            model_name="fleet",
            name="finalized_at",
            field=models.DateTimeField(blank=True, help_text="When this fleet was finalized", null=True),
        ),
        migrations.AddField(
            model_name="fleet",
            name="finalized_by",
            field=models.ForeignKey(
                blank=True,
                help_text="User who finalized this fleet",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="finalized_fleets",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddIndex(
            model_name="fleet",
            index=models.Index(fields=["finalized"], name="aapayout_fl_finaliz_659fbc_idx"),
        ),
    ]
